@@ -1,13 +1,14 @@
 /* archimedes.c -- This code is a simulator for Submicron 2D III-V
    semiconductor Devices (along with SiO2). It implements the Monte Carlo method 
-   and a  simplified version of MEP model for the simulation of the 
+   and a simplified version of MEP model for the simulation of the 
    semiclassical Boltzmann equation for both electrons and holes.
-   It also includes the quantum effects by means of effective
-   potential method. It is now able to simulate applied
+   It also includes some quantum effects by means of effective
+   potential method. It is also able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Jean Michel Sellier
+   Copyright (C) 2004-2011 Jean Michel Sellier
    <jeanmichel.sellier@gmail.com>
+   <jsellier@purdue.edu>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,9 +27,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 0.9.0
+// Version   : release 1.5.0
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 01 April 2009, West Lafayette, Indiana, USA, Jean Michel Sellier.
+// Last Revision : 15 Sept. 2011, Carry le Rouet, France, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -49,6 +50,11 @@
 
 // Preprocessor Definitions
 #define real double
+#define ON 1
+#define OFF 0
+#define KANE 0
+#define PARABOLIC 1
+#define FULL 2
 #define MN3 4
 #define NXM 308
 #define NYM 308
@@ -70,7 +76,7 @@
 // definition of the material reference table
 #define NOAMTIA 16   // Number Of All Material Taken Into Account (excluding SiO2)
 // ********************
-#define iSIO2 -1      // reference number to Silicon Oxide
+#define iSIO2 -1     // reference number to Silicon Oxide
 #define SILICON 0    // reference number to Silicon
 #define GAAS 1       // reference number to GaAs
 #define GERMANIUM 2  // reference number to Germanium
@@ -97,7 +103,6 @@
 #include "sign.h"
 #include "mm.h"
 #include "mm2.h"
-#include "definitionoffunctions.h"
 // ===============================
 
 // All integers here...
@@ -112,6 +117,10 @@ int SIO2_DOWN_FLAG;
 int FARADAYFLAG;
 int i_dom[NXM+1][NYM+1];
 int NOVALLEY[NOAMTIA+1];
+int ACOUSTICPHONONS;
+int OPTICALPHONONS;
+int IMPURITYPHONONS;
+int CONDUCTION_BAND;
 
 // All "real"'s here...
 real u2d[NXM+1][NYM+1][MN3+1];
@@ -122,7 +131,7 @@ real dx,dy;
 real TEMPO=0.,TF;
 real LX,LY;
 real TL,DT;
-real mstar2,msh;
+real mstar2;
 real BKTQ,QH;
 real SMH[NOAMTIA+1][3];
 real HHM[NOAMTIA+1][3];
@@ -163,6 +172,8 @@ real DA[NOAMTIA+1];
 real UL[NOAMTIA+1];
 real EMIN[NOAMTIA+1][4];
 real XVAL[NOAMTIA+1];
+real LATTCONST[NOAMTIA+1];
+real CB_FULL[NOAMTIA+1][11];
 
 // All structures here...
 time_t binarytime;
@@ -177,6 +188,37 @@ FILE *fp;
 // All strings here...
 static char *progname;
 
+#include "poissonbcs.h"
+#include "faradaybcs.h"
+#include "media.h"
+#include "saveoutput2dmeshformat.h"
+#include "saveoutput2dgnuplot.h"
+#include "saveoutput2dholegnuplot.h"
+#include "saveoutput2dholemeshformat.h"
+#include "saveoutputfiles.h"
+#include "quantumeffectivepotential.h"
+#include "electric_field.h"
+#include "faraday.h"
+#include "random.h"
+#include "mcparameters.h"
+#include "deviceconfig.h"
+#include "particlecreation.h"
+#include "drift.h"
+#include "scattering.h"
+#include "ensemblemontecarlo.h"
+#include "charge.h"
+#include "computecurrents.h"
+#include "MEP_interpolation.h"
+#include "electron_relaxation.h"
+#include "HMEPbcs.h"
+#include "ParabMEP2D.h"
+#include "Hole_bcs.h"
+#include "holemep2d.h"
+#include "hole_relaxation.h"
+#include "updating.h"
+#include "readinputfile.h"
+//#include "SaveRappture.h"
+
 int 
 main(int argc,char* argv[])
 {
@@ -230,7 +272,7 @@ main(int argc,char* argv[])
       /* TRANSLATORS: --help output 1
          no-wrap */
       printf("\
-GNU archimedes, a simulator for submicron silicon devices.\n");
+GNU archimedes, a simulator for submicron and nanoscale semiconductor devices.\nCopyright (C) 2004-2011 Jean Michel D. Sellier.\n");
       printf ("\n");
       /* TRANSLATORS: --help output 2
          no-wrap */
@@ -250,7 +292,7 @@ Usage: %s [OPTION] file...\n",progname);
          your translation!
          no-wrap */
       printf ("\
-Report bugs to jeanmichel.sellier@gmail.com\n");
+Report bugs to jeanmichel.sellier@gmail.com or jsellier@purdue.edu\n");
 
       exit (0);
     }
@@ -258,17 +300,17 @@ Report bugs to jeanmichel.sellier@gmail.com\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.8.0\n");
+      printf("archimedes - GNU archimedes 1.5.0\n");
       /* xgettext: no-wrap */
-      printf("\n");
+      printf("");
       printf("\
-Copyright (C) %s Sellier Jean Michel.\n\
+Copyright (C) %s Jean Michel D. Sellier.\n\n\
 There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A\n\
 PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
 of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n",
-              "2004, 2005, 2006, 2007, 2008","Archimedes");
+              "2004 - 2011","Archimedes");
       exit (0);
     }
   else if (z){
@@ -285,49 +327,53 @@ For more information about these matters, see the file named COPYING.\n",
 // Material constants here!
 // ========================
 // Silicon electrons in the X-valley
-// Germanium electrons in the X-valley
-// All the other semiconductor compounds have electrons in the Gamma- and L-valley
-// definition of the number of valley for every material
-     NOVALLEY[SILICON]=1;
-     NOVALLEY[GERMANIUM]=1;
-     NOVALLEY[GAAS]=2;
-     NOVALLEY[INSB]=2;
-     NOVALLEY[ALSB]=2;
-     NOVALLEY[ALXINXSB]=2;
-     NOVALLEY[ALXIN1XSB]=2;
-     NOVALLEY[ALAS]=2;
-     NOVALLEY[ALP]=2;
-     NOVALLEY[GAP]=2;
-     NOVALLEY[GASB]=2;
-     NOVALLEY[INAS]=2;
-     NOVALLEY[INP]=2;
-     NOVALLEY[INXGA1XAS]=2;
-     NOVALLEY[INXAL1XAS]=2;
-     NOVALLEY[INXGAXXAS]=2;
+// Germanium electrons in the Gamma-valley
+// GaAs electrons in the Gamma- and L-valley
+// For the others, see comments below
+     NOVALLEY[SILICON]=1;    // X-valley
+     NOVALLEY[GERMANIUM]=1;  // G-valley
+     NOVALLEY[GAAS]=2;       // G and L-valleys
+     NOVALLEY[INSB]=1;       // G valley
+     NOVALLEY[ALSB]=1;       // G-valley
+     NOVALLEY[ALXINXSB]=1;   // G-valley
+     NOVALLEY[ALXIN1XSB]=1;  // G-valley
+     NOVALLEY[ALAS]=1;       // G-valley
+     NOVALLEY[ALP]=1;        // G-valley
+     NOVALLEY[GAP]=1;        // G-valley
+     NOVALLEY[GASB]=1;       // G-valley
+     NOVALLEY[INAS]=1;       // G-valley
+     NOVALLEY[INP]=1;        // G-valley
+     NOVALLEY[INXGA1XAS]=1;  // only G-valley
+     NOVALLEY[INXAL1XAS]=1;  // G-valley
+     NOVALLEY[INXGAXXAS]=1;  // only G-valley
 // Dielectric constant for Silicon Oxide SiO2
-     EPSRSIO2=17.0*EPS0;
+     EPSRSIO2=3.9*EPS0;         // see http://en.wikipedia.org/wiki/Relative_permittivity
 // Dielectric constant for Semiconducting materials
-     EPSR[SILICON]=11.7*EPS0;
-     EPSR[GERMANIUM]=16.2*EPS0;
-     EPSR[GAAS]=12.90*EPS0;
-     EPSR[INSB]=17.65*EPS0;
-     EPSR[ALSB]=12.04*EPS0;
-     EPSR[ALAS]=10.06;
-     EPSR[ALP]=9.80;
-     EPSR[GAP]=11.10;
-     EPSR[GASB]=15.69;
-     EPSR[INAS]=15.15;
-     EPSR[INP]=12.61;
+// STATIC
+// ======
+     EPSR[SILICON]=11.68;       // see http://en.wikipedia.org/wiki/Relative_permittivity
+     EPSR[GERMANIUM]=16.2;      // see http://www.ioffe.ru/SVA/NSM/Semicond/Ge/basic.html
+     EPSR[GAAS]=12.90;          // see http://www.ioffe.ru/SVA/NSM/Semicond/GaAs/basic.html
+     EPSR[INSB]=16.8;           // see http://www.ioffe.ru/SVA/NSM/Semicond/InSb/basic.html
+     EPSR[ALSB]=12.04;          // Fischetti conversations
+     EPSR[ALAS]=12.90-2.84;     // see http://www.ioffe.ru/SVA/NSM/Semicond/AlGaAs/basic.html (x=1.0)
+     EPSR[ALP]=9.80;            // Fischetti conversations
+     EPSR[GAP]=11.10;           // see http://www.ioffe.ru/SVA/NSM/Semicond/GaP/basic.html
+     EPSR[GASB]=15.69;          // see http://www.ioffe.ru/SVA/NSM/Semicond/GaSb/basic.html
+     EPSR[INAS]=15.15;          // see http://www.ioffe.ru/SVA/NSM/Semicond/InAs/basic.html
+     EPSR[INP]=12.50;           // see http://www.ioffe.ru/SVA/NSM/Semicond/InP/basic.html 
 // III-V semiconductor compounds high frequency dieletric constant
-     EPF[GAAS]=10.92;
-     EPF[INSB]=15.68;
-     EPF[ALSB]=9.88;
-     EPF[ALAS]=8.16;
-     EPF[ALP]=7.54;
-     EPF[GAP]=9.08;
-     EPF[GASB]=14.44;
-     EPF[INAS]=12.75;
-     EPF[INP]=9.61;
+// HIGH FREQUENCY
+// ==============
+     EPF[GAAS]=10.89;           // see http://www.ioffe.ru/SVA/NSM/Semicond/GaAs/basic.html
+     EPF[INSB]=15.68;           // Fischetti conversations
+     EPF[ALSB]=9.88;            // Fiscehtti conversations
+     EPF[ALAS]=10.89-2.73;      // see http://www.ioffe.ru/SVA/NSM/Semicond/AlGaAs/basic.html (x=1.0)
+     EPF[ALP]=7.54;             // Fischetti conversations
+     EPF[GAP]=9.11;             // see http://www.ioffe.ru/SVA/NSM/Semicond/GaP/basic.html
+     EPF[GASB]=14.44;           // see http://www.ioffe.ru/SVA/NSM/Semicond/GaSb/basic.html
+     EPF[INAS]=12.3;            // see http://www.ioffe.ru/SVA/NSM/Semicond/InAs/basic.html
+     EPF[INP]=9.61;             // see http://www.ioffe.ru/SVA/NSM/Semicond/InP/basic.html
      int ii;
      for(ii=0;ii<NOAMTIA;ii++){
        int i;
@@ -337,111 +383,103 @@ For more information about these matters, see the file named COPYING.\n",
          ZF[ii][i]=0.;
        }
      }
-// Silicon optical phonon scattering energy (eV)
-     HWO[SILICON][0]=0.0120;
-     HWO[SILICON][1]=0.0185;
-     HWO[SILICON][2]=0.0190;
-     HWO[SILICON][3]=0.0474;
-     HWO[SILICON][4]=0.0612;
-     HWO[SILICON][5]=0.0590;
-// Germanium optical phonon scattering energy (eV)
-     HWO[GERMANIUM][0]=0.09;
-// III-V semiconductor compounds optical phonon scattering energy (eV)
-     HWO[GAAS][0]=0.03536;
-     HWO[INSB][0]=0.0282;
-     HWO[ALSB][0]=0.0360;
-     HWO[ALAS][0]=0.05009;
-     HWO[ALP][0]=0.06212;
-     HWO[GAP][0]=0.04523;
-     HWO[GASB][0]=0.02529;
-     HWO[INAS][0]=0.03008;
-     HWO[INP][0]=0.04240;
-// Silicon optical coupling constants (eV/m)
-     DTK[SILICON][0]=0.05e11;
-     DTK[SILICON][1]=0.08e11;
-     DTK[SILICON][2]=0.03e11;
-     DTK[SILICON][3]=0.20e11;
-     DTK[SILICON][4]=1.14e11;
-     DTK[SILICON][5]=0.20e11;
-// Germanium optical coupling constants (eV/m)
-     DTK[GERMANIUM][0]=1.889e11;
-// III-V semiconductor compounds optical coupling constant (eV/m)
-     DTK[GAAS][0]=1.11e11;
-     DTK[INSB][0]=0.47e11;
-     DTK[ALSB][0]=0.55e11;
-     DTK[ALAS][0]=3.0e11;
-     DTK[ALP][0]=0.95e11;
-     DTK[GAP][0]=5.33e11;
-     DTK[GASB][0]=0.94e11;
-     DTK[INAS][0]=3.59e11;
-     DTK[INP][0]=2.46e11;
-// Silicon optical phonon Z-factor
-     ZF[SILICON][0]=1.;
-     ZF[SILICON][1]=1.;
-     ZF[SILICON][2]=4.;
-     ZF[SILICON][3]=4.;
-     ZF[SILICON][4]=1.;
-     ZF[SILICON][5]=4.;
-// Germanium optical phonon Z-factor
-     ZF[GERMANIUM][0]=1.;
-// III-V semiconductor compounds optical phonon Z-factor
-     ZF[GAAS][0]=1.;
-     ZF[INSB][0]=1.;
-     ZF[ALSB][0]=1.;
-     ZF[ALAS][0]=1.;
-     ZF[ALP][0]=1.;
-     ZF[GAP][0]=1.;
-     ZF[GASB][0]=1.;
-     ZF[INAS][0]=1.;
-     ZF[INP][0]=1.;
-// Silicon Crystal Density (Kg/m^3)
-     RHO[SILICON]=2330.;
-// Germanium Crystal Density (Kg/m^3)
-     RHO[GERMANIUM]=5320.;
-// III-V semiconductor compounds Crystal Density (Kg/m^3)
-     RHO[GAAS]=5360.;
-     RHO[INSB]=5790.;
-     RHO[ALSB]=4288.;
-     RHO[ALAS]=5650.;
-     RHO[ALP]=7410.;
-     RHO[GAP]=5850.;
-     RHO[GASB]=3970.;
-     RHO[INAS]=4280.;
-     RHO[INP]=5130.;
-// Silicon acoustic deformation potential (Joule)
-     DA[SILICON]=9.*1.60217733e-19;
-// Germanium acoustic deformation potential (Joule)
-     DA[GERMANIUM]=9.*1.60217733e-19;
-// III-V semiconductor compounds acoustic deformation potential (Joule)
-     DA[GAAS]=7.*1.60217733e-19;
-     DA[INSB]=5.96*1.60217733e-19;
-     DA[ALSB]=4.6*1.60217733e-19;
-     DA[ALAS]=9.3*1.60217733e-19;
-     DA[ALP]=9.3*1.60217733e-19;
-     DA[GAP]=7.4*1.60217733e-19;
-     DA[GASB]=9.*1.60217733e-19;
-     DA[INAS]=8.2*1.60217733e-19;
-     DA[INP]=6.2*1.60217733e-19;
-// Silicon longitudinal sound velocity (m/sec)
-     UL[SILICON]=9040.;
-// Germanium longitudinal sound velocity (m/sec)
-     UL[GERMANIUM]=5400.;
-// III-V semiconductor compounds longitudinal sound velocity (m/sec)
-     UL[GAAS]=5240.;
-     UL[INSB]=4060.;
-     UL[ALSB]=4600.;
-     UL[ALAS]=5650.;
-     UL[ALP]=7410.;
-     UL[GAP]=5850.;
-     UL[GASB]=3970.;
-     UL[INAS]=4280.;
-     UL[INP]=5130.;
-// Silicon minimum energy
-     EMIN[SILICON][1]=0.0;
-// Germanium minimum energy
-     EMIN[GERMANIUM][1]=0.173;
-// III-V semiconductor compounds minimum energy of GAMMA-valley
-     EMIN[GAAS][1]=0.0;
+// Optical phonon scattering energy (eV)
+     HWO[SILICON][0]=0.0120;    // Sellier, Tomizawa
+     HWO[SILICON][1]=0.0185;    // Sellier, Tomizawa
+     HWO[SILICON][2]=0.0190;    // Sellier, Tomizawa
+     HWO[SILICON][3]=0.0474;    // Sellier, Tomizawa
+     HWO[SILICON][4]=0.0612;    // Sellier, Tomizawa
+     HWO[SILICON][5]=0.0590;    // Sellier, Tomizawa
+     HWO[GERMANIUM][0]=0.03704; // Fischetti
+     HWO[GAAS][0]=0.03536;      // Fischetti
+     HWO[INSB][0]=0.02404;      // Fischetti
+     HWO[ALSB][0]=0.0360;       // Fischetti
+     HWO[ALAS][0]=0.05009;      // Fischetti
+     HWO[ALP][0]=0.06211;       // Fischetti
+     HWO[GAP][0]=0.04523;       // Fischetti
+     HWO[GASB][0]=0.02529;      // Fischetti
+     HWO[INAS][0]=0.03008;      // Fischetti
+     HWO[INP][0]=0.04240;       // Fischetti
+// Optical coupling constants (eV/m)
+     DTK[SILICON][0]=0.05e11;     // Jacoboni Reggiani
+     DTK[SILICON][1]=0.08e11;     // Jacoboni Reggiani
+     DTK[SILICON][2]=0.03e11;     // Jacoboni Reggiani
+     DTK[SILICON][3]=0.20e11;     // Jacoboni Reggiani
+     DTK[SILICON][4]=1.14e11;     // Jacoboni Reggiani
+     DTK[SILICON][5]=0.20e11;     // Jacoboni Reggiani
+     DTK[GERMANIUM][0]=0.0;       // Jacoboni Reggiani
+     DTK[GERMANIUM][1]=0.079e11;  // Jacoboni Reggiani
+     DTK[GERMANIUM][2]=0.0;       // Jacoboni Reggiani
+     DTK[GERMANIUM][3]=0.0;       // Jacoboni Reggiani
+     DTK[GERMANIUM][4]=0.95e11;   // Jacoboni Reggiani
+     DTK[GERMANIUM][5]=0.0;       // Jacoboni Reggiani
+     DTK[GAAS][0]=1.11e11;        // Sellier, Tomizawa
+     DTK[INSB][0]=0.47e11; // see ???
+     DTK[ALSB][0]=0.55e11; // see ???
+     DTK[ALAS][0]=3.0e11;  // see ???
+     DTK[ALP][0]=0.95e11;  // see ???
+     DTK[GAP][0]=5.33e11;  // see ???
+     DTK[GASB][0]=0.94e11; // see ???
+     DTK[INAS][0]=3.59e11; // see ???
+     DTK[INP][0]=2.46e11;  // see ???
+// Optical phonon Z-factor
+     ZF[SILICON][0]=1.;   // Sellier
+     ZF[SILICON][1]=1.;   // Sellier
+     ZF[SILICON][2]=4.;   // Sellier
+     ZF[SILICON][3]=4.;   // Sellier
+     ZF[SILICON][4]=1.;   // Sellier
+     ZF[SILICON][5]=4.;   // Sellier
+     ZF[GERMANIUM][0]=1.; // see ???
+     ZF[GAAS][0]=1.;      // Sellier
+     ZF[INSB][0]=1.;      // see ???
+     ZF[ALSB][0]=1.;      // see ???
+     ZF[ALAS][0]=1.;      // see ???
+     ZF[ALP][0]=1.;       // see ???
+     ZF[GAP][0]=1.;       // see ???
+     ZF[GASB][0]=1.;      // see ???
+     ZF[INAS][0]=1.;      // see ???
+     ZF[INP][0]=1.;       // see ???
+// Crystal Density (Kg/m^3)
+     RHO[SILICON]=2.33e3;   // Fischetti conversations
+     RHO[GERMANIUM]=5.32e3; // Fischetti conversations
+     RHO[GAAS]=5.36e3;      // Fischetti conversations
+     RHO[INSB]=5.78e3;      // Fischetti conversations
+     RHO[ALSB]=4.26e3;      // Fischetti conversations
+     RHO[ALAS]=3.76e3;      // Fischetti conversations
+     RHO[ALP]=2.40e3;       // Fischetti conversations
+     RHO[GAP]=4.14e3;       // Fischetti conversations
+     RHO[GASB]=5.61e3;      // Fischetti conversations
+     RHO[INAS]=5.67e3;      // Fischetti conversations
+     RHO[INP]=4.81e3;       // Fischetti conversations
+// Acoustic deformation potential (Joule)
+     DA[SILICON]=9.*Q;      // Fischetti -- Jacoboni Reggiani
+     DA[GERMANIUM]=9.*Q;    // Fischetti -- Jacoboni Reggiani
+     DA[GAAS]=7.*Q;         // Fischetti - Gamma valley
+     DA[INSB]=7.*Q;         // Fischetti
+     DA[ALSB]=4.6*Q;        // Fischetti
+     DA[ALAS]=9.3*Q;        // Fischetti
+     DA[ALP]=9.3*Q;         // Fischetti
+     DA[GAP]=7.4*Q;         // Fischetti
+     DA[GASB]=9.*Q;         // Fischetti
+     DA[INAS]=8.2*Q;        // Fischetti
+     DA[INP]=6.2*Q;         // Fischetti
+// Longitudinal sound velocity (m/sec)
+     UL[SILICON]=9.18e3;   // Fischetti
+     UL[GERMANIUM]=5.4e3;  // Fischetti
+     UL[GAAS]=5.24e3;      // Fischetti
+     UL[INSB]=3.41e3;      // Fischetti
+     UL[ALSB]=4.25e3;      // Fischetti
+     UL[ALAS]=5.65e3;      // Fischetti
+     UL[ALP]=7.41e3;       // Fischetti
+     UL[GAP]=5.85e3;       // Fischetti
+     UL[GASB]=3.97e3;      // Fischetti
+     UL[INAS]=4.28e3;      // Fischetti
+     UL[INP]=5.13e3;       // Fischetti
+// Band minimum energy
+// first valley
+     EMIN[SILICON][1]=0.0;     // Sellier, Fischetti, etc.
+     EMIN[GERMANIUM][1]=0.173; 
+     EMIN[GAAS][1]=0.0;        // Tomizawa
      EMIN[INSB][1]=0.0;
      EMIN[ALSB][1]=0.507;
      EMIN[ALAS][1]=0.767;
@@ -450,41 +488,49 @@ For more information about these matters, see the file named COPYING.\n",
      EMIN[GASB][1]=0.0;
      EMIN[INAS][1]=0.0;
      EMIN[INP][1]=0.0;
-// III-V semiconductor compounds minimum energy of L-valley (eV)
+// eventual second valley
      EMIN[GAAS][2]=0.323;
-     EMIN[INSB][2]=1.038;
-     EMIN[ALSB][2]=0.292;
-     EMIN[ALAS][2]=0.332;
-     EMIN[ALP][2]=0.824;
-     EMIN[GAP][2]=0.415;
-     EMIN[GASB][2]=0.217;
-     EMIN[INAS][2]=1.078;
-     EMIN[INP][2]=0.832;
+
 // Definition of effective mass for all materials in all valleys
-     MSTAR[SILICON][1]=0.32;
-     MSTAR[GAAS][1]=0.067; // Gamma-valley
-     MSTAR[GAAS][2]=0.350; // L-valley
-     MSTAR[GERMANIUM][1]=0.22;
-     MSTAR[INSB][1]=0.013;
-     MSTAR[INSB][2]=0.442;
-     MSTAR[ALSB][1]=0.14;
-     MSTAR[ALSB][2]=0.442;
-     MSTAR[ALAS][1]=0.149;
-     MSTAR[ALAS][2]=pow(1.456*pow(0.165,2.),1./3.);
-     MSTAR[ALP][1]=0.166;
-     MSTAR[ALP][2]=pow(1.556*pow(0.162,2.),1./3.);
-     MSTAR[GAP][1]=0.122;
-     MSTAR[GAP][2]=pow(1.498*pow(0.358,2.),1./3.);
-     MSTAR[GASB][1]=0.048;
-     MSTAR[GASB][2]=pow(1.4*pow(0.139,2.),1./3.);
-     MSTAR[INAS][1]=0.031;
-     MSTAR[INAS][2]=pow(1.590*pow(0.326,2.),1./3.);
-     MSTAR[INP][1]=0.083;
-     MSTAR[INP][2]=pow(1.893*pow(0.425,2.),1./3.);
-// non-parabolicity coefficient for Silicon
-     alphaK[SILICON][1]=0.5;
-// non-parabolicity coefficient for Germanium
-     alphaK[GERMANIUM][1]=0.65;
+     MSTAR[SILICON][1]=0.32;     // see Sellier, Tomizawa, etc.
+     MSTAR[GAAS][1]=0.067;       // Gamma-valley -- see Tomizawa
+     MSTAR[GAAS][2]=0.350;       // L-valley     -- see Tomizawa
+     MSTAR[GERMANIUM][1]=0.12;   // Gamma valley -- see http://ecee.colorado.edu/~bart/book/effmass.htm#long
+     MSTAR[INSB][1]=0.0135;      // Gamma-valley -- see Ram-Mohan
+     MSTAR[ALSB][1]=0.14;        // Gamma-valley -- See Ram-Mohan
+     MSTAR[ALAS][1]=0.149;       // Gamma-valley -- see Ram-Mohan J.App.Phys. Vol.89, Num.11
+     MSTAR[ALP][1]=0.22;         // Gamma-valley -- see Ram-Mohan
+     MSTAR[GAP][1]=0.13;         // Gamma-valley -- see Ram-Mohan J.App.Phys. Vol.89, Num.11
+     MSTAR[GASB][1]=0.039;       // Gamma-valley -- see Ram-Mohan
+     MSTAR[INAS][1]=0.026;       // Gamma-valley -- see Ram-Mohan J.App.Phys. Vol.89, Num.11
+     MSTAR[INP][1]=0.0795;       // Gamma-valley -- see Ram-Mohan
+// non-parabolicity coefficients
+     alphaK[SILICON][1]=0.5;    // see Sellier, Tomizawa
+     alphaK[GERMANIUM][1]=0.3;  // Gamma valley - Jacoboni Reggiani
+// Lattice constants
+     LATTCONST[GAAS]=565.35e-12;       // CODATA
+     LATTCONST[SILICON]=543.102e-12;   // CODATA
+     LATTCONST[GERMANIUM]=564.613e-12; // CODATA
+     LATTCONST[ALP]=545.10e-12;        // CODATA
+     LATTCONST[ALAS]=565.05e-12;       // CODATA
+     LATTCONST[ALSB]=613.55e-12;       // CODATA
+     LATTCONST[GAP]=545.12e-12;        // CODATA
+     LATTCONST[GASB]=609.59e-12;       // CODATA
+     LATTCONST[INP]=586.87e-12;        // CODATA
+     LATTCONST[INAS]=605.83e-12;       // CODATA
+     LATTCONST[INSB]=647.9e-12;        // CODATA
+// sp3s* Conduction Band calculated parameters for full band simulations
+#include "Silicon.h"
+#include "GaAs.h"
+#include "Germanium.h"
+#include "AlP.h"
+#include "AlAs.h"
+#include "AlSb.h"
+#include "GaP.h"
+#include "GaSb.h"
+#include "InP.h"
+#include "InAs.h"
+#include "InSb.h"
 // ======================================================
 // ======================================================
 
@@ -498,6 +544,7 @@ For more information about these matters, see the file named COPYING.\n",
 // Read the geometrical and physical description of the MESFET
 // ===========================================================
      Read_Input_File();
+// ===========================================================
 
 // III-V Semiconductor materials energy gap (depending on the lattice temperature)
      printf("\n");
@@ -524,61 +571,42 @@ For more information about these matters, see the file named COPYING.\n",
      EG[INP]=1.445-3.296e-4*TL;
      printf("EG[INP]         = %g\n",EG[INP]);
      printf("\n");
+
+     if(CONDUCTION_BAND==KANE || CONDUCTION_BAND==PARABOLIC || CONDUCTION_BAND==FULL){
+      // USED WHATEVER IS THE CONDUCTION BAND FOR THE INITIAL PSUEDO WAVE VECTOR
+      // OF THE PSEUDO PARTICLES
 // all the following non-parabolicity coefficients depend on lattice temperature
 // non-parabolicity coefficient for GaAs in the GAMMA-valley
-     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/(EG[GAAS]+EMIN[GAAS][1]);//expected value = 0.611
-     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
+      alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/(EG[GAAS]+EMIN[GAAS][1]);//expected value = 0.611
+      printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
 // non-parabolicity coefficient for GaAs in the L-valley
-     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/(EG[GAAS]+EMIN[GAAS][2]);//expected value = 0.242;
-     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
+      alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/(EG[GAAS]+EMIN[GAAS][2]);//expected value = 0.242;
+      printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
 // non-parabolicity coefficient for InSb in the GAMMA-valley
-     alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/(EG[INSB]+EMIN[INSB][1]);//5.59;
-     printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
-// non-parabolicity coefficient for InSb in the L-valley
-     alphaK[INSB][2]=pow(1.-MSTAR[INSB][2],2.)/(EG[INSB]+EMIN[INSB][2]);//1.789;
-     printf("alphaK_L[InSb]     = %g\n",alphaK[INSB][2]);
+      alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/(EG[INSB]+EMIN[INSB][1]);//5.59;
+      printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
 // non-parabolicity coefficient for AlSb in the GAMMA-valley
-     alphaK[ALSB][1]=pow(1.-MSTAR[ALSB][1],2.)/(EG[ALSB]+EMIN[ALSB][1]);//0.321;
-     printf("alphaK_gamma[AlSb] = %g\n",alphaK[ALSB][1]);
-// non-parabolicity coefficient for AlSb in the L-valley
-     alphaK[ALSB][2]=pow(1.-MSTAR[ALSB][2],2.)/(EG[ALSB]+EMIN[ALSB][2]);//0.135;
-     printf("alphaK_L[AlSb]     = %g\n",alphaK[ALSB][2]);
+      alphaK[ALSB][1]=pow(1.-MSTAR[ALSB][1],2.)/(EG[ALSB]+EMIN[ALSB][1]);//0.321;
+      printf("alphaK_gamma[AlSb] = %g\n",alphaK[ALSB][1]);
 // non-parabolicity coefficient for AlAs in the GAMMA-valley
-     alphaK[ALAS][1]=pow(1.-MSTAR[ALAS][1],2.)/(EG[ALAS]+EMIN[ALAS][1]);
-     printf("alphaK_gamma[AlAs] = %g\n",alphaK[ALAS][1]);
-// non-parabolicity coefficient for AlAs in the L-valley
-     alphaK[ALAS][2]=pow(1.-MSTAR[ALAS][2],2.)/(EG[ALAS]+EMIN[ALAS][2]);
-     printf("alphaK_L[AlAs]     = %g\n",alphaK[ALAS][2]);
+      alphaK[ALAS][1]=pow(1.-MSTAR[ALAS][1],2.)/(EG[ALAS]+EMIN[ALAS][1]);
+      printf("alphaK_gamma[AlAs] = %g\n",alphaK[ALAS][1]);
 // non-parabolicity coefficient for AlP in the GAMMA-valley
-     alphaK[ALP][1]=pow(1.-MSTAR[ALP][1],2.)/(EG[ALP]+EMIN[ALP][1]);
-     printf("alphaK_gamma[AlP] = %g\n",alphaK[ALP][1]);
-// non-parabolicity coefficient for AlAs in the L-valley
-     alphaK[ALP][2]=pow(1.-MSTAR[ALP][2],2.)/(EG[ALP]+EMIN[ALP][2]);
-     printf("alphaK_L[AlP]     = %g\n",alphaK[ALP][2]);
+      alphaK[ALP][1]=pow(1.-MSTAR[ALP][1],2.)/(EG[ALP]+EMIN[ALP][1]);
+      printf("alphaK_gamma[AlP] = %g\n",alphaK[ALP][1]);
 // non-parabolicity coefficient for GaP in the GAMMA-valley
-     alphaK[GAP][1]=pow(1.-MSTAR[GAP][1],2.)/(EG[GAP]+EMIN[GAP][1]);
-     printf("alphaK_gamma[GaP] = %g\n",alphaK[GAP][1]);
-// non-parabolicity coefficient for GaP in the L-valley
-     alphaK[GAP][2]=pow(1.-MSTAR[GAP][2],2.)/(EG[GAP]+EMIN[GAP][2]);
-     printf("alphaK_L[GaP]     = %g\n",alphaK[GAP][2]);
+      alphaK[GAP][1]=pow(1.-MSTAR[GAP][1],2.)/(EG[GAP]+EMIN[GAP][1]);
+      printf("alphaK_gamma[GaP] = %g\n",alphaK[GAP][1]);
 // non-parabolicity coefficient for GaSb in the GAMMA-valley
-     alphaK[GASB][1]=pow(1.-MSTAR[GASB][1],2.)/(EG[GASB]+EMIN[GASB][1]);
-     printf("alphaK_gamma[GaSb] = %g\n",alphaK[GASB][1]);
-// non-parabolicity coefficient for GaSb in the L-valley
-     alphaK[GASB][2]=pow(1.-MSTAR[GASB][2],2.)/(EG[GASB]+EMIN[GASB][2]);
-     printf("alphaK_L[GaSb]     = %g\n",alphaK[GASB][2]);
+      alphaK[GASB][1]=pow(1.-MSTAR[GASB][1],2.)/(EG[GASB]+EMIN[GASB][1]);
+      printf("alphaK_gamma[GaSb] = %g\n",alphaK[GASB][1]);
 // non-parabolicity coefficient for InAs in the GAMMA-valley
-     alphaK[INAS][1]=pow(1.-MSTAR[INAS][1],2.)/(EG[INAS]+EMIN[INAS][1]);
-     printf("alphaK_gamma[InAs] = %g\n",alphaK[INAS][1]);
-// non-parabolicity coefficient for InAs in the L-valley
-     alphaK[INAS][2]=pow(1.-MSTAR[INAS][2],2.)/(EG[INAS]+EMIN[INAS][2]);
-     printf("alphaK_L[InAs]     = %g\n",alphaK[INAS][2]);
+      alphaK[INAS][1]=pow(1.-MSTAR[INAS][1],2.)/(EG[INAS]+EMIN[INAS][1]);
+      printf("alphaK_gamma[InAs] = %g\n",alphaK[INAS][1]);
 // non-parabolicity coefficient for InP in the GAMMA-valley
-     alphaK[INP][1]=pow(1.-MSTAR[INP][1],2.)/(EG[INP]+EMIN[INP][1]);
-     printf("alphaK_gamma[InP] = %g\n",alphaK[INP][1]);
-// non-parabolicity coefficient for InP in the L-valley
-     alphaK[INP][2]=pow(1.-MSTAR[INP][2],2.)/(EG[INP]+EMIN[INP][2]);
-     printf("alphaK_L[InP]     = %g\n",alphaK[INP][2]);
+      alphaK[INP][1]=pow(1.-MSTAR[INP][1],2.)/(EG[INP]+EMIN[INP][1]);
+      printf("alphaK_gamma[InP] = %g\n",alphaK[INP][1]);
+     }
 
 // Semiconductor compounds
 // ***
@@ -702,13 +730,13 @@ For more information about these matters, see the file named COPYING.\n",
       printf("\n");
       MCdevice_config();
      }
-     printf("/n");
+     printf("\n");
 // HERE IS THE SIMULATION
 // ======================
      for(c=1;c<=ITMAX;c++) updating(Model_Number);
 // Here we save the outputs
 // ========================
-     SaveRappture();
+//     SaveRappture();
      SaveOutputFiles(File_Format,0);
      printf("Final Output has been saved\n");
     }
@@ -739,45 +767,6 @@ For more information about these matters, see the file named COPYING.\n",
    return(EXIT_SUCCESS); // Successfull exit
 }
 
-/* ------------------- Inclusione funzioni --------------------- */
-
-// ****************************************************
-
-// ======================================================================
-// Modif. 06 ago.2004 - 01 Apr.2009, West Lafayette, IN, USA, J.M.Sellier
-// ======================================================================
-#include "poissonbcs.h"
-#include "faradaybcs.h"
-#include "media.h"
-#include "saveoutput2dmeshformat.h"
-#include "saveoutput2dgnuplot.h"
-#include "saveoutput2dholegnuplot.h"
-#include "saveoutput2dholemeshformat.h"
-#include "saveoutputfiles.h"
-#include "electric_field.h"
-#include "faraday.h"
-#include "quantumeffectivepotential.h"
-#include "random.h"
-#include "mcparameters.h"
-#include "deviceconfig.h"
-#include "particlecreation.h"
-#include "ensemblemontecarlo.h"
-#include "drift.h"
-#include "scattering.h"
-#include "charge.h"
-#include "updating.h"
-#include "readinputfile.h"
-#include "computecurrents.h"
-#include "electron_relaxation.h"
-#include "ParabMEP2D.h"
-#include "HMEPbcs.h"
-#include "MEP_interpolation.h"
-#include "holemep2d.h"
-#include "hole_relaxation.h"
-#include "Hole_bcs.h"
-#include "SaveRappture.h"
-// =========================================
-
 /* archimedes.c ends here */
 
 // ***********************************************************************
