@@ -1,15 +1,18 @@
-/* ensemblemontecarlo.h -- This file is part of Archimedes release 0.0.2.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+/* ensemblemontecarlo.h -- This file is part of Archimedes release 1.2.0.
+   Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
-   electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   electrons and holes. It includes some quantum effects by means 
+   of effective potential method. It is also able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004-2011 Jean Michel Sellier
+   <jeanmichel.sellier@gmail.com>
+   <jsellier@purdue.edu>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,14 +21,13 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 12 Jan.2005, Siracusa, J.M.Sellier
+// Last modif. : 25 Aug.2011, Carry le Rouet, France, J.M.Sellier
 // ######################################################
 
 // Ensemble Monte Carlo method
@@ -53,9 +55,21 @@ EMC(void)
     while(TS<=tdt){
        tau=TS-ti;
        drift(tau);
-       scat();
+       i=(int)(X/dx)+1;
+       j=(int)(Y/dy)+1;
+       if(i<=1)  i=1;
+       if(j<=1)  j=1;
+       if(i>=nx) i=nx;
+       if(j>=ny) j=ny;
+       scat(i_dom[i][j]);
        ti=TS;
-       TS=ti-log(rnd())/GM;
+       i=(int)(X/dx)+1;
+       j=(int)(Y/dy)+1;
+       if(i<=1)  i=1;
+       if(j<=1)  j=1;
+       if(i>=nx) i=nx;
+       if(j>=ny) j=ny;
+       TS=ti-log(rnd())/GM[i_dom[i][j]];
     }
     tau=tdt-ti;
     drift(tau);
